==> haskell-cabal-install-parsers-0.4.5-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-install-parsers
version:              0.4.5
visibility:           public
id:                   cabal-install-parsers-0.4.5-ArhMLxlX25oLuHtY12Ntbe
key:                  cabal-install-parsers-0.4.5-ArhMLxlX25oLuHtY12Ntbe
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  41414dd0566e5bc9e922d147a67a24f9
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cabal-install-parsers-0.4.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cabal-install-parsers-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.4.5-ArhMLxlX25oLuHtY12Ntbe
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-2QGjkfeUzb9GAwOHYL9mgm base-4.16.4.0
    base16-bytestring-1.0.2.0-2zrcaj2dASWLOg7ed8DTQL binary-0.8.9.0
    binary-instances-1.0.4-HfgvYnW5qnSCpZLjG4yn4F bytestring-0.11.4.0
    containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-371Jt5DwAMz5e6UHJQG3Qm deepseq-1.4.6.1
    directory-1.3.6.2 filepath-1.4.2.2
    lukko-0.1.1.3-JzdqELWzXE1GySMLJfQy6p
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL parsec-3.1.15.0
    pretty-1.1.3.6 tar-0.5.1.1-LuHavtc4dd2CbXF9ulAH4q text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-install-parsers-0.4.5-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-install-parsers
version:              0.4.5
visibility:           public
id:                   cabal-install-parsers-0.4.5-3Xiux30G7Ek3GkYpGKLe2W
key:                  cabal-install-parsers-0.4.5-3Xiux30G7Ek3GkYpGKLe2W
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  8d31f0200a0d54d34b95bb42c08a959b
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cabal-install-parsers-0.4.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cabal-install-parsers-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-parsers
hs-libraries:         HScabal-install-parsers-0.4.5-3Xiux30G7Ek3GkYpGKLe2W
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j base-4.16.4.0
    base16-bytestring-1.0.2.0-2zrcaj2dASWLOg7ed8DTQL binary-0.8.9.0
    binary-instances-1.0.4-JX7r73dWb3L9XAgI5A6Iq5 bytestring-0.11.4.0
    containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-371Jt5DwAMz5e6UHJQG3Qm deepseq-1.4.6.1
    directory-1.3.6.2 filepath-1.4.2.2
    lukko-0.1.1.3-KBSyN6Zo0D78fb7LuNgIaz
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL parsec-3.1.15.0
    pretty-1.1.3.6 tar-0.5.1.1-LuHavtc4dd2CbXF9ulAH4q text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
